@@ -71,6 +71,13 @@ void MainWindow::PlayRemoteVideo()
   SetCurrentFile(video->GetOriginalUrl());
 }
 
+
+void MainWindow::StopRemoteVideo()
+{
+  player->Stop();
+  player->SetStatusLabel(tr("Failed"));
+}
+
 void MainWindow::CreateMenus()
 {
   // Actions
@@ -176,7 +183,11 @@ void MainWindow::CreateMenus()
 
 void MainWindow::SetTitle(const QString& title)
 {
-  setWindowTitle(tr("%1 - %2").arg(title).arg(tr("TubeBrowser")));
+  if (!title.isEmpty()) {
+    setWindowTitle(tr("%1 - TubeBrowser").arg(title));
+  } else {
+    setWindowTitle(tr("TubeBrowser"));
+  }
 }
 
 void MainWindow::About()
@@ -264,7 +275,7 @@ void MainWindow::UpdateRecentFileActions()
 
   int max = qMin(files.size(), (int)MAX_RECENT_FILES);
   for (int i=0; i<max; ++i) {
-    QString text = tr("&%1 %2").arg(i + 1).arg(files[i]);
+    QString text = QString("&%1 %2").arg(i + 1).arg(files[i]);
     recent_actions[i]->setText(text);
     recent_actions[i]->setData(files[i]);
     recent_actions[i]->setVisible(true);
@@ -357,6 +368,7 @@ void MainWindow::PlayUrl(const QUrl& url)
     video = VideoFactory::Create(url);
     video->FindVideo();
     connect(video, SIGNAL(Finished()), this, SLOT(PlayRemoteVideo()));
+    connect(video, SIGNAL(Error()), this, SLOT(StopRemoteVideo()));
   }
 }
 
