@@ -19,6 +19,10 @@ public slots:
 
 private slots:
   void SelectItem(QListWidgetItem*);
+  void ClearAll();
+  void RemoveEntry();
+  void LoadPlaylist();
+  void SavePlaylist();
 
 signals:
   void Closed();
