@@ -34,6 +34,25 @@ QString Video::GetOriginalUrl()
   return orig_url;
 }
 
+bool Video::HasErrors(QNetworkReply *reply)
+{
+  if (reply->error() != QNetworkReply::NoError) {
+    qDebug() << "error=" << reply->errorString();
+    reply->abort();
+    emit Error();
+    return true;
+  }
+
+  if (reply->attribute(QNetworkRequest::HttpStatusCodeAttribute) != 200) {
+    qDebug() << "status_code=" << reply->errorString();
+    reply->abort();
+    emit Error();
+    return true;
+  }
+
+  return false;
+}
+
 Video* VideoFactory::Create(const QUrl& url)
 {
   QString tmp = url.toString();
@@ -43,7 +62,7 @@ Video* VideoFactory::Create(const QUrl& url)
     return new Video_YouTube(url);
   } else if (tmp.indexOf("www.dailymotion.com") != -1) {
     return new Video_Dailymotion(url);
-  } else if (tmp.indexOf("www.vimeo.com") != -1) {
+  } else if (tmp.indexOf("vimeo.com") != -1) {
     return new Video_Vimeo(url);
   } else if (tmp.indexOf("www.veoh.com") != -1) {
     return new Video_Veoh(url);
@@ -51,6 +70,10 @@ Video* VideoFactory::Create(const QUrl& url)
     return new Video_Tube8(url);
   } else if (tmp.indexOf("www.yourfilehost.com") != -1) {
     return new Video_YourFileHost(url);
+  } else if (tmp.indexOf("www.bofunk.com") != -1) {
+    return new Video_Bofunk(url);
+  } else if (tmp.indexOf("video.fc2.com")) {
+    return new Video_Fc2(url);
   } else {
     return new Video_Generic(url);
   }
@@ -58,11 +81,19 @@ Video* VideoFactory::Create(const QUrl& url)
 
 void Video_Generic::FindVideo()
 {
+  // TODO: this does not work currently, so throw an error.
+  emit Error();
+  return;
+
   manager->get(QNetworkRequest(QUrl(orig_url)));
 }
 
 void Video_Generic::ReplyFinished(QNetworkReply *reply)
 {
+  if (HasErrors(reply)) {
+    return;
+  }
+
   QString content_type = reply->rawHeader("Content-Type");
   qDebug() << "content_type=" << content_type;
 
@@ -85,6 +116,10 @@ void Video_YouTube::FindVideo()
 
 void Video_YouTube::ReplyFinished(QNetworkReply *reply)
 {
+  if (HasErrors(reply)) {
+    return;
+  }
+
   QString content(reply->readAll());
   QRegExp regex;
   QString video_id;
@@ -96,6 +131,8 @@ void Video_YouTube::ReplyFinished(QNetworkReply *reply)
     qDebug() << "video_id=" << video_id;
   } else {
     qDebug() << "Couldn't get video ID.";
+    emit Error();
+    return;
   }
 
   regex.setPattern(" \"t\": \"([^\"]+)\"");
@@ -128,6 +165,10 @@ void Video_Tube8::FindVideo()
 
 void Video_Tube8::ReplyFinished(QNetworkReply *reply)
 {
+  if (HasErrors(reply)) {
+    return;
+  }
+
   QString content(reply->readAll());
   QRegExp regex;
 
@@ -137,6 +178,8 @@ void Video_Tube8::ReplyFinished(QNetworkReply *reply)
     qDebug() << "location=" << location;
   } else {
     qDebug() << "Couldn't get video ID.";
+    emit Error();
+    return;
   }
 
   // Try to find the video's title.
@@ -158,6 +201,10 @@ void Video_Dailymotion::FindVideo()
 
 void Video_Dailymotion::ReplyFinished(QNetworkReply *reply)
 {
+  if (HasErrors(reply)) {
+    return;
+  }
+
   QString content(reply->readAll());
   QRegExp regex;
 
@@ -168,6 +215,8 @@ void Video_Dailymotion::ReplyFinished(QNetworkReply *reply)
     qDebug() << "location=" << location;
   } else {
     qDebug() << "Couldn't get video ID.";
+    emit Error();
+    return;
   }
 
   // Try to find the video's title.
@@ -184,7 +233,7 @@ void Video_Dailymotion::ReplyFinished(QNetworkReply *reply)
 
 void Video_Vimeo::FindVideo()
 {
-  QRegExp regex("http://www.vimeo.com/([0-9]+)");
+  QRegExp regex("vimeo.com/([0-9]+)");
   QString tmp = orig_url;
 
   if (regex.indexIn(orig_url) != -1) {
@@ -199,6 +248,10 @@ void Video_Vimeo::FindVideo()
 
 void Video_Vimeo::ReplyFinished(QNetworkReply *reply)
 {
+  if (HasErrors(reply)) {
+    return;
+  }
+
   QString content(reply->readAll());
   QRegExp regex;
   QString video_id;
@@ -211,6 +264,8 @@ void Video_Vimeo::ReplyFinished(QNetworkReply *reply)
     qDebug() << "video_id=" << video_id;
   } else {
     qDebug() << "Couldn't get video ID.";
+    emit Error();
+    return;
   }
 
   regex.setPattern("<request_signature>([a-z0-9]+)</");
@@ -219,6 +274,8 @@ void Video_Vimeo::ReplyFinished(QNetworkReply *reply)
     qDebug() << "signature=" << signature;
   } else {
     qDebug() << "Couldn't get request signature.";
+    emit Error();
+    return;
   }
 
   regex.setPattern("<request_signature_expires>([0-9]+)</");
@@ -227,6 +284,8 @@ void Video_Vimeo::ReplyFinished(QNetworkReply *reply)
     qDebug() << "signature_expires=" << signature_expires;
   } else {
     qDebug() << "Couldn't get request signature expires.";
+    emit Error();
+    return;
   }
 
   // Try to find the video's title.
@@ -258,6 +317,10 @@ void Video_Veoh::FindVideo()
 
 void Video_Veoh::ReplyFinished(QNetworkReply *reply)
 {
+  if (HasErrors(reply)) {
+    return;
+  }
+
   QString content(reply->readAll());
   QRegExp regex;
 
@@ -267,6 +330,8 @@ void Video_Veoh::ReplyFinished(QNetworkReply *reply)
     qDebug() << "location=" << location;
   } else {
     qDebug() << "Couldn't get video URL.";
+    emit Error();
+    return;
   }
 
   // Try to find the video's title.
@@ -295,6 +360,10 @@ void Video_YourFileHost::FindVideo()
 
 void Video_YourFileHost::ReplyFinished(QNetworkReply *reply)
 {
+  if (HasErrors(reply)) {
+    return;
+  }
+
   if (reply->url().toString().indexOf("/media.php?cat=video&file=") != -1) {
     ReplyFinished1(reply);
   } else {
@@ -314,6 +383,8 @@ void Video_YourFileHost::ReplyFinished1(QNetworkReply *reply)
     qDebug() << "api=" << api;
   } else {
     qDebug() << "Couldn't get video API URL.";
+    emit Error();
+    return;
   }
 
   // Try to find the video's title.
@@ -334,6 +405,82 @@ void Video_YourFileHost::ReplyFinished2(QNetworkReply *reply)
     qDebug() << "location=" << location;
   } else {
     qDebug() << "Couldn't get video URL.";
+    emit Error();
+    return;
+  }
+
+  emit Finished();
+}
+
+void Video_Bofunk::FindVideo()
+{
+  manager->get(QNetworkRequest(QUrl(orig_url)));
+}
+
+void Video_Bofunk::ReplyFinished(QNetworkReply *reply)
+{
+  if (HasErrors(reply)) {
+    return;
+  }
+
+  QString content(reply->readAll());
+  QRegExp regex;
+
+  regex.setPattern("<embed src=\"/w/([^\"]+)\"");
+  if (regex.indexIn(content) != -1) {
+    location = "http://media.bofunk.com/media/flvs/" + regex.cap(1) + ".flv";
+    qDebug() << "location=" << location;
+  } else {
+    qDebug() << "Couldn't get video URL.";
+    emit Error();
+    return;
+  }
+
+  // Try to find the video's title.
+  regex.setPattern("<meta name=\"title\" content=\"([^\"]+)\">");
+  if (regex.indexIn(content) != -1) {
+    title = regex.cap(1);
+    qDebug() << "title=" << title;
+  } else {
+    qDebug() << "Couldn't get video title.";
+  }
+
+  emit Finished();
+}
+
+void Video_Fc2::FindVideo()
+{
+  manager->get(QNetworkRequest(QUrl(orig_url)));
+}
+
+void Video_Fc2::ReplyFinished(QNetworkReply *reply)
+{
+  if (HasErrors(reply)) {
+    return;
+  }
+
+  QString content(reply->readAll());
+  QRegExp regex;
+
+  regex.setPattern(
+    "'(http://video[0-9].fc2.com/up/)thumb(/[0-9]+/[0-9]+/[0-9]/)"
+    "FCUT_([^.]+).gif',");
+  if (regex.indexIn(content) != -1) {
+    location = regex.cap(1) + "flv" + regex.cap(2) + regex.cap(3) + ".flv";
+    qDebug() << "location=" << location;
+  } else {
+    qDebug() << "Couldn't get video URL.";
+    emit Error();
+    return;
+  }
+
+  // Try to find the video's title.
+  regex.setPattern("<meta name=\"description\" content=\"([^\"]+)\" />");
+  if (regex.indexIn(content) != -1) {
+    title = regex.cap(1);
+    qDebug() << "title=" << title;
+  } else {
+    qDebug() << "Couldn't get video title.";
   }
 
   emit Finished();
