@@ -24,12 +24,14 @@ public slots:
 
 signals:
   void Finished();
+  void Error();
 
 protected:
   QNetworkAccessManager *manager;
   QString orig_url;
   QString location;
   QString title;
+  bool HasErrors(QNetworkReply *reply);
 };
 
 class VideoFactory
@@ -126,4 +128,28 @@ private:
   void ReplyFinished2(QNetworkReply*);
 };
 
+class Video_Bofunk: public Video
+{
+  Q_OBJECT
+
+public:
+  Video_Bofunk(const QUrl& url): Video(url) {};
+  void FindVideo();
+
+public slots:
+  void ReplyFinished(QNetworkReply*);
+};
+
+class Video_Fc2: public Video
+{
+  Q_OBJECT
+
+public:
+  Video_Fc2(const QUrl& url): Video(url) {};
+  void FindVideo();
+
+public slots:
+  void ReplyFinished(QNetworkReply*);
+};
+
 #endif /* _VIDEO_H_ */
