@@ -5,182 +5,182 @@
     <name>MainWindow</name>
     <message>
         <location filename="../src/mainwindow.cc" line="25"/>
-        <location filename="../src/mainwindow.cc" line="179"/>
+        <location filename="../src/mainwindow.cc" line="189"/>
         <source>TubeBrowser</source>
         <translation>TubeBrowser</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cc" line="77"/>
+        <location filename="../src/mainwindow.cc" line="78"/>
+        <source>Failed</source>
+        <translation>失敗</translation>
+    </message>
+    <message>
+        <location filename="../src/mainwindow.cc" line="84"/>
         <source>&amp;Open</source>
         <translation>開く(&amp;O)</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cc" line="81"/>
-        <location filename="../src/mainwindow.cc" line="218"/>
+        <location filename="../src/mainwindow.cc" line="88"/>
+        <location filename="../src/mainwindow.cc" line="229"/>
         <source>Open URL...</source>
         <translation>URLを開く...</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cc" line="82"/>
+        <location filename="../src/mainwindow.cc" line="89"/>
         <source>Ctrl+L</source>
         <translation>Ctrl+L</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cc" line="85"/>
+        <location filename="../src/mainwindow.cc" line="92"/>
         <source>Copy Current URL</source>
         <translation>現在のURLをコピー</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cc" line="88"/>
+        <location filename="../src/mainwindow.cc" line="95"/>
         <source>Download Current Video</source>
         <translation>現在の動画をダウンロード</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cc" line="92"/>
+        <location filename="../src/mainwindow.cc" line="99"/>
         <source>E&amp;xit</source>
         <translation>終了(&amp;X)</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cc" line="95"/>
+        <location filename="../src/mainwindow.cc" line="102"/>
         <source>Playlist</source>
         <translation>プレイリスト</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cc" line="101"/>
+        <location filename="../src/mainwindow.cc" line="108"/>
         <source>Seek Bar</source>
         <translation>シークバー</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cc" line="107"/>
+        <location filename="../src/mainwindow.cc" line="114"/>
         <source>On Top</source>
         <translation>最前面表示</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cc" line="109"/>
+        <location filename="../src/mainwindow.cc" line="116"/>
         <source>Ctrl+T</source>
         <translation>Ctrl+T</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cc" line="113"/>
+        <location filename="../src/mainwindow.cc" line="120"/>
         <source>P&amp;lay</source>
         <translation>再生(&amp;P)</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cc" line="116"/>
+        <location filename="../src/mainwindow.cc" line="123"/>
         <source>&amp;Stop</source>
         <translation>停止(&amp;S)</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cc" line="119"/>
+        <location filename="../src/mainwindow.cc" line="126"/>
         <source>Pause</source>
         <translation>一時停止</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cc" line="122"/>
+        <location filename="../src/mainwindow.cc" line="129"/>
         <source>Home Page</source>
         <translation>ホームページ</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cc" line="125"/>
+        <location filename="../src/mainwindow.cc" line="132"/>
         <source>&amp;About</source>
         <translation>情報(&amp;A)</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cc" line="136"/>
+        <location filename="../src/mainwindow.cc" line="143"/>
         <source>Clear All</source>
         <translation>すべてクリア</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cc" line="141"/>
+        <location filename="../src/mainwindow.cc" line="148"/>
         <source>&amp;File</source>
         <translation>ファイル(&amp;F)</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cc" line="145"/>
+        <location filename="../src/mainwindow.cc" line="152"/>
         <source>Recent Files</source>
         <translation>最近見たファイル</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cc" line="160"/>
+        <location filename="../src/mainwindow.cc" line="167"/>
         <source>&amp;View</source>
         <translation>表示(&amp;V)</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cc" line="167"/>
+        <location filename="../src/mainwindow.cc" line="174"/>
         <source>&amp;Play</source>
         <translation>再生(&amp;P)</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cc" line="172"/>
+        <location filename="../src/mainwindow.cc" line="179"/>
         <source>&amp;Help</source>
         <translation>ヘルプ(&amp;H)</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cc" line="179"/>
-        <source>%1 - %2</source>
-        <translation>%1 - %2</translation>
+        <location filename="../src/mainwindow.cc" line="187"/>
+        <source>%1 - TubeBrowser</source>
+        <translation>%1 - TubeBrowser</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cc" line="184"/>
+        <location filename="../src/mainwindow.cc" line="195"/>
         <source>About TubeBrowser</source>
         <translation>TubeBrowserについて</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cc" line="193"/>
+        <location filename="../src/mainwindow.cc" line="204"/>
         <source>Choose a file to open</source>
         <translation>開くファイルを選択してください</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cc" line="195"/>
+        <location filename="../src/mainwindow.cc" line="206"/>
         <source>FLV files (*.flv);;All files (*.*)</source>
         <translation>FLVファイル(*.flv);;すべてのファイル(*.*)</translation>
     </message>
     <message>
-        <location filename="../src/mainwindow.cc" line="219"/>
+        <location filename="../src/mainwindow.cc" line="230"/>
         <source>Enter the address of the file you would like to open:</source>
         <translation>開きたいファイルのアドレスを入力してください:</translation>
     </message>
-    <message>
-        <location filename="../src/mainwindow.cc" line="267"/>
-        <source>&amp;%1 %2</source>
-        <translation>&amp;%1 - %2</translation>
-    </message>
 </context>
 <context>
     <name>Player</name>
     <message>
-        <location filename="../src/player.cc" line="194"/>
+        <location filename="../src/player.cc" line="195"/>
         <source>Playing</source>
         <translation>再生中</translation>
     </message>
     <message>
         <location filename="../src/player.cc" line="79"/>
-        <location filename="../src/player.cc" line="206"/>
+        <location filename="../src/player.cc" line="207"/>
         <source>Stopped</source>
         <translation>停止</translation>
     </message>
     <message>
-        <location filename="../src/player.cc" line="220"/>
+        <location filename="../src/player.cc" line="221"/>
         <source>Paused</source>
         <translation>一時停止</translation>
     </message>
     <message>
-        <location filename="../src/player.cc" line="276"/>
+        <location filename="../src/player.cc" line="282"/>
         <source>Play</source>
         <translation>再生</translation>
     </message>
     <message>
-        <location filename="../src/player.cc" line="280"/>
+        <location filename="../src/player.cc" line="286"/>
         <source>Pause</source>
         <translation>一時停止</translation>
     </message>
     <message>
-        <location filename="../src/player.cc" line="284"/>
+        <location filename="../src/player.cc" line="290"/>
         <source>Stop</source>
         <translation>停止</translation>
     </message>
     <message>
-        <location filename="../src/player.cc" line="294"/>
+        <location filename="../src/player.cc" line="300"/>
         <source>Volume</source>
         <translation>音量</translation>
     </message>
@@ -208,23 +208,23 @@
         <translation>削除</translation>
     </message>
     <message>
-        <location filename="../src/playlist.cc" line="42"/>
+        <location filename="../src/playlist.cc" line="43"/>
         <source>Playlist</source>
         <translation>プレイリスト</translation>
     </message>
     <message>
-        <location filename="../src/playlist.cc" line="113"/>
+        <location filename="../src/playlist.cc" line="114"/>
         <source>Choose a file to open</source>
         <translation>開くファイルを選択してください</translation>
     </message>
     <message>
-        <location filename="../src/playlist.cc" line="115"/>
-        <location filename="../src/playlist.cc" line="145"/>
+        <location filename="../src/playlist.cc" line="116"/>
+        <location filename="../src/playlist.cc" line="146"/>
         <source>Playlist files (*.txt);;All files (*.*)</source>
         <translation>プレイリストファイル(*.txt);;すべてのファイル(*.*)</translation>
     </message>
     <message>
-        <location filename="../src/playlist.cc" line="143"/>
+        <location filename="../src/playlist.cc" line="144"/>
         <source>Save playlist as ...</source>
         <translation>プレイリストを保存...</translation>
     </message>
